Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(814)

Unified Diff: media/base/audio_hash.h

Issue 1534273002: Switch to standard integer types in media/. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: more Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/base/audio_hash.h
diff --git a/media/base/audio_hash.h b/media/base/audio_hash.h
index ec733832f7817d001a7caf60f310af975ccb4145..4f47d97c50c2d21e7830d9580abf517f94491b38 100644
--- a/media/base/audio_hash.h
+++ b/media/base/audio_hash.h
@@ -7,7 +7,6 @@
#include <string>
-#include "base/basictypes.h"
#include "base/strings/string_piece.h"
#include "media/base/media_export.h"
@@ -46,9 +45,9 @@ class MEDIA_EXPORT AudioHash {
// positives related to incorrect sample position. Value chosen by dice roll.
float audio_hash_[6];
// The total number of samples processed per channel. Uses a uint32 instead
// of size_t so overflows on 64-bit and 32-bit machines are equivalent.
- uint32 sample_count_;
+ uint32_t sample_count_;
DISALLOW_COPY_AND_ASSIGN(AudioHash);
};
@@ -46,9 +45,9 @@ class MEDIA_EXPORT AudioHash {
// positives related to incorrect sample position. Value chosen by dice roll.
float audio_hash_[6];
- // The total number of samples processed per channel. Uses a uint32 instead
+ // The total number of samples processed per channel. Uses a uint32_t instead
// of size_t so overflows on 64-bit and 32-bit machines are equivalent.

Powered by Google App Engine
This is Rietveld 408576698